package v1

// DO NOT EDIT: this file is automatically generated by ./tools/generator in this repo

import (
	"gitlab.com/signald/signald-go/signald/client-protocol/v0"
)

type Request struct {
	ID      string `json:"id" yaml:"id"`
	Version string `json:"version" yaml:"version"`
	Type    string `json:"type" yaml:"type"`
}

// AcceptInvitationRequest: Accept a v2 group invitation. Note that you must have a profile name set to join groups.
type AcceptInvitationRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	GroupID string `json:"groupID,omitempty" yaml:"groupID,omitempty"`
}

// Account: A local account in signald
type Account struct {
	AccountId string       `json:"account_id,omitempty" yaml:"account_id,omitempty"` // The primary identifier on the account, included with all requests to signald for this account. Previously called 'username'
	Address   *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`       // The address of this account
	DeviceId  int32        `json:"device_id,omitempty" yaml:"device_id,omitempty"`   // The Signal device ID. Official Signal mobile clients (iPhone and Android) have device ID = 1, while linked devices such as Signal Desktop or Signal iPad have higher device IDs.
}

type AccountList struct {
	Accounts []*Account `json:"accounts,omitempty" yaml:"accounts,omitempty"`
}

// AddLinkedDeviceRequest: Link a new device to a local Signal account
type AddLinkedDeviceRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	Uri     string `json:"uri,omitempty" yaml:"uri,omitempty"`         // the tsdevice:/ uri provided (typically in qr code form) by the new device
}

type AllIdentityKeyList struct {
	IdentityKeys []*IdentityKeyList `json:"identity_keys,omitempty" yaml:"identity_keys,omitempty"`
}

// ApproveMembershipRequest: approve a request to join a group
type ApproveMembershipRequest struct {
	Request
	Account string         `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	GroupID string         `json:"groupID,omitempty" yaml:"groupID,omitempty"`
	Members []*JsonAddress `json:"members,omitempty" yaml:"members,omitempty"` // list of requesting members to approve
}

type Capabilities struct {
	Gv1Migration bool `json:"gv1-migration,omitempty" yaml:"gv1-migration,omitempty"`
	Gv2          bool `json:"gv2,omitempty" yaml:"gv2,omitempty"`
	Storage      bool `json:"storage,omitempty" yaml:"storage,omitempty"`
}

type CreateGroupRequest struct {
	Request
	Account    string         `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	Avatar     string         `json:"avatar,omitempty" yaml:"avatar,omitempty"`
	MemberRole string         `json:"member_role,omitempty" yaml:"member_role,omitempty"` // The role of all members other than the group creator. Options are ADMINISTRATOR or DEFAULT (case insensitive)
	Members    []*JsonAddress `json:"members,omitempty" yaml:"members,omitempty"`
	Timer      int32          `json:"timer,omitempty" yaml:"timer,omitempty"` // the message expiration timer
	Title      string         `json:"title,omitempty" yaml:"title,omitempty"`
}

// DeleteAccountRequest: delete all account data signald has on disk, and optionally delete the account from the server as well. Note that this is not "unlink" and will delete the entire account, even from a linked device.
type DeleteAccountRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to delete
	Server  bool   `json:"server,omitempty" yaml:"server,omitempty"`   // delete account information from the server as well (default false)
}

type DeviceInfo struct {
	Created  int64  `json:"created,omitempty" yaml:"created,omitempty"`
	ID       int64  `json:"id,omitempty" yaml:"id,omitempty"`
	LastSeen int64  `json:"lastSeen,omitempty" yaml:"lastSeen,omitempty"`
	Name     string `json:"name,omitempty" yaml:"name,omitempty"`
}

type FinishLinkRequest struct {
	Request
	DeviceName string `json:"device_name,omitempty" yaml:"device_name,omitempty"`
	SessionId  string `json:"session_id,omitempty" yaml:"session_id,omitempty"`
}

// GenerateLinkingURIRequest: Generate a linking URI. Typically this is QR encoded and scanned by the primary device. Submit the returned session_id with a finish_link request.
type GenerateLinkingURIRequest struct {
	Request
}

// GetAllIdentities: get all known identity keys
type GetAllIdentities struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
}

// GetGroupRequest: Query the server for the latest state of a known group
type GetGroupRequest struct {
	Request
	Account  string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	GroupID  string `json:"groupID,omitempty" yaml:"groupID,omitempty"`
	Revision int32  `json:"revision,omitempty" yaml:"revision,omitempty"` // the latest known revision, default value (-1) forces fetch from server
}

// GetIdentitiesRequest: Get information about a known keys for a particular address
type GetIdentitiesRequest struct {
	Request
	Account string       `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	Address *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"` // address to get keys for
}

// GetLinkedDevicesRequest: list all linked devices on a Signal account
type GetLinkedDevicesRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
}

// GetProfileRequest: Get all information available about a user
type GetProfileRequest struct {
	Request
	Account string       `json:"account,omitempty" yaml:"account,omitempty"` // the signald account to use
	Address *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"` // the address to look up
	Async   bool         `json:"async,omitempty" yaml:"async,omitempty"`     // return results from local store immediately, refreshing from server if needed. If false (default), block until all pending profiles have been retrieved.
}

// GroupAccessControl: group access control settings. Options for each controlled action are: UNKNOWN, ANY, MEMBER, ADMINISTRATOR, UNSATISFIABLE and UNRECOGNIZED
type GroupAccessControl struct {
	Attributes string `json:"attributes,omitempty" yaml:"attributes,omitempty"` // who can edit group info
	Link       string `json:"link,omitempty" yaml:"link,omitempty"`             // UNSATISFIABLE when the group link is disabled, ADMINISTRATOR when the group link is enabled but an administrator must approve new members, ANY when the group link is enabled and no approval is required
	Members    string `json:"members,omitempty" yaml:"members,omitempty"`       // who can add members
}

// GroupInfo: A generic type that is used when the group version is not known
type GroupInfo struct {
	V1 *JsonGroupInfo   `json:"v1,omitempty" yaml:"v1,omitempty"`
	V2 *JsonGroupV2Info `json:"v2,omitempty" yaml:"v2,omitempty"`
}

// GroupLinkInfoRequest: Get information about a group from a signal.group link
type GroupLinkInfoRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to use
	Uri     string `json:"uri,omitempty" yaml:"uri,omitempty"`         // the signald.group link
}

type GroupList struct {
	Groups       []*JsonGroupV2Info `json:"groups,omitempty" yaml:"groups,omitempty"`
	LegacyGroups []*JsonGroupInfo   `json:"legacyGroups,omitempty" yaml:"legacyGroups,omitempty"`
}

type GroupMember struct {
	JoinedRevision int32  `json:"joined_revision,omitempty" yaml:"joined_revision,omitempty"`
	Role           string `json:"role,omitempty" yaml:"role,omitempty"` // possible values are: UNKNOWN, DEFAULT, ADMINISTRATOR and UNRECOGNIZED
	UUID           string `json:"uuid,omitempty" yaml:"uuid,omitempty"`
}

type IdentityKey struct {
	Added        int64  `json:"added,omitempty" yaml:"added,omitempty"`               // the first time this identity key was seen
	QrCodeData   string `json:"qr_code_data,omitempty" yaml:"qr_code_data,omitempty"` // base64-encoded QR code data
	SafetyNumber string `json:"safety_number,omitempty" yaml:"safety_number,omitempty"`
	TrustLevel   string `json:"trust_level,omitempty" yaml:"trust_level,omitempty"` // One of TRUSTED_UNVERIFIED, TRUSTED_VERIFIED or UNTRUSTED
}

// IdentityKeyList: a list of identity keys associated with a particular address
type IdentityKeyList struct {
	Address    *JsonAddress   `json:"address,omitempty" yaml:"address,omitempty"`
	Identities []*IdentityKey `json:"identities,omitempty" yaml:"identities,omitempty"`
}

// JoinGroupRequest: Join a group using the a signal.group URL. Note that you must have a profile name set to join groups.
type JoinGroupRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to interact with
	Uri     string `json:"uri,omitempty" yaml:"uri,omitempty"`         // The signal.group URL
}

type JsonAddress struct {
	Number string `json:"number,omitempty" yaml:"number,omitempty"` // An e164 phone number, starting with +. Currently the only available user-facing Signal identifier.
	Relay  string `json:"relay,omitempty" yaml:"relay,omitempty"`
	UUID   string `json:"uuid,omitempty" yaml:"uuid,omitempty"` // A UUID, the unique identifier for a particular Signal account.
}

type JsonBlockedListMessage struct {
	Addresses []*JsonAddress `json:"addresses,omitempty" yaml:"addresses,omitempty"`
	GroupIds  []string       `json:"groupIds,omitempty" yaml:"groupIds,omitempty"`
}

type JsonDataMessage struct {
	Attachments      []*v0.JsonAttachment `json:"attachments,omitempty" yaml:"attachments,omitempty"` // files attached to the incoming message
	Body             string               `json:"body,omitempty" yaml:"body,omitempty"`               // the text body of the incoming message.
	Contacts         []*v0.SharedContact  `json:"contacts,omitempty" yaml:"contacts,omitempty"`       // if the incoming message has a shared contact, the contact's information will be here
	EndSession       bool                 `json:"endSession,omitempty" yaml:"endSession,omitempty"`
	ExpiresInSeconds int32                `json:"expiresInSeconds,omitempty" yaml:"expiresInSeconds,omitempty"` // the expiry timer on the incoming message. Clients should delete records of the message within this number of seconds
	Group            *JsonGroupInfo       `json:"group,omitempty" yaml:"group,omitempty"`                       // if the incoming message was sent to a v1 group, information about that group will be here
	GroupV2          *JsonGroupV2Info     `json:"groupV2,omitempty" yaml:"groupV2,omitempty"`                   // is the incoming message was sent to a v2 group, basic identifying information about that group will be here. For full information, use list_groups
	Mentions         []*JsonMention       `json:"mentions,omitempty" yaml:"mentions,omitempty"`                 // list of mentions in the message
	Previews         []*v0.JsonPreview    `json:"previews,omitempty" yaml:"previews,omitempty"`                 // if the incoming message has a link preview, information about that preview will be here
	ProfileKeyUpdate bool                 `json:"profileKeyUpdate,omitempty" yaml:"profileKeyUpdate,omitempty"`
	Quote            *JsonQuote           `json:"quote,omitempty" yaml:"quote,omitempty"`               // if the incoming message is a quote or reply to another message, this will contain information about that message
	Reaction         *JsonReaction        `json:"reaction,omitempty" yaml:"reaction,omitempty"`         // if the message adds or removes a reaction to another message, this will indicate what change is being made
	RemoteDelete     *v0.RemoteDelete     `json:"remoteDelete,omitempty" yaml:"remoteDelete,omitempty"` // if the inbound message is deleting a previously sent message, indicates which message should be deleted
	Sticker          *v0.JsonSticker      `json:"sticker,omitempty" yaml:"sticker,omitempty"`           // if the incoming message is a sticker, information about the sicker will be here
	Timestamp        int64                `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`       // the timestamp that the message was sent at, according to the sender's device. This is used to uniquely identify this message for things like reactions and quotes.
	ViewOnce         bool                 `json:"viewOnce,omitempty" yaml:"viewOnce,omitempty"`         // indicates the message is a view once message. View once messages typically include no body and a single image attachment. Official Signal clients will prevent the user from saving the image, and once the user has viewed the image once they will destroy the image.
}

type JsonGroupInfo struct {
	AvatarId int64          `json:"avatarId,omitempty" yaml:"avatarId,omitempty"`
	GroupId  string         `json:"groupId,omitempty" yaml:"groupId,omitempty"`
	Members  []*JsonAddress `json:"members,omitempty" yaml:"members,omitempty"`
	Name     string         `json:"name,omitempty" yaml:"name,omitempty"`
	Type     string         `json:"type,omitempty" yaml:"type,omitempty"`
}

type JsonGroupJoinInfo struct {
	AddFromInviteLink    int32  `json:"addFromInviteLink,omitempty" yaml:"addFromInviteLink,omitempty"`
	GroupID              string `json:"groupID,omitempty" yaml:"groupID,omitempty"`
	MemberCount          int32  `json:"memberCount,omitempty" yaml:"memberCount,omitempty"`
	PendingAdminApproval bool   `json:"pendingAdminApproval,omitempty" yaml:"pendingAdminApproval,omitempty"`
	Revision             int32  `json:"revision,omitempty" yaml:"revision,omitempty"`
	Title                string `json:"title,omitempty" yaml:"title,omitempty"`
}

type JsonGroupV2Info struct {
	AccessControl       *GroupAccessControl `json:"accessControl,omitempty" yaml:"accessControl,omitempty"` // current access control settings for this group
	Avatar              string              `json:"avatar,omitempty" yaml:"avatar,omitempty"`               // path to the group's avatar on local disk, if available
	Description         string              `json:"description,omitempty" yaml:"description,omitempty"`
	ID                  string              `json:"id,omitempty" yaml:"id,omitempty"`
	InviteLink          string              `json:"inviteLink,omitempty" yaml:"inviteLink,omitempty"`     // the signal.group link, if applicable
	MemberDetail        []*GroupMember      `json:"memberDetail,omitempty" yaml:"memberDetail,omitempty"` // detailed member list
	Members             []*JsonAddress      `json:"members,omitempty" yaml:"members,omitempty"`
	PendingMemberDetail []*GroupMember      `json:"pendingMemberDetail,omitempty" yaml:"pendingMemberDetail,omitempty"` // detailed pending member list
	PendingMembers      []*JsonAddress      `json:"pendingMembers,omitempty" yaml:"pendingMembers,omitempty"`
	RequestingMembers   []*JsonAddress      `json:"requestingMembers,omitempty" yaml:"requestingMembers,omitempty"`
	Revision            int32               `json:"revision,omitempty" yaml:"revision,omitempty"`
	Timer               int32               `json:"timer,omitempty" yaml:"timer,omitempty"`
	Title               string              `json:"title,omitempty" yaml:"title,omitempty"`
}

type JsonMention struct {
	Length int32  `json:"length,omitempty" yaml:"length,omitempty"` // The length of the mention represented in the message. Seems to always be 1 but included here in case that changes.
	Start  int32  `json:"start,omitempty" yaml:"start,omitempty"`   // The number of characters in that the mention starts at. Note that due to a quirk of how signald encodes JSON, if this value is 0 (for example if the first character in the message is the mention) the field won't show up.
	UUID   string `json:"uuid,omitempty" yaml:"uuid,omitempty"`     // The UUID of the account being mentioned
}

type JsonMessageEnvelope struct {
	CallMessage              *v0.JsonCallMessage    `json:"callMessage,omitempty" yaml:"callMessage,omitempty"`
	DataMessage              *JsonDataMessage       `json:"dataMessage,omitempty" yaml:"dataMessage,omitempty"`
	HasContent               bool                   `json:"hasContent,omitempty" yaml:"hasContent,omitempty"`
	HasLegacyMessage         bool                   `json:"hasLegacyMessage,omitempty" yaml:"hasLegacyMessage,omitempty"`
	IsUnidentifiedSender     bool                   `json:"isUnidentifiedSender,omitempty" yaml:"isUnidentifiedSender,omitempty"`
	Receipt                  *v0.JsonReceiptMessage `json:"receipt,omitempty" yaml:"receipt,omitempty"`
	Relay                    string                 `json:"relay,omitempty" yaml:"relay,omitempty"`
	ServerDeliveredTimestamp int64                  `json:"serverDeliveredTimestamp,omitempty" yaml:"serverDeliveredTimestamp,omitempty"`
	ServerTimestamp          int64                  `json:"serverTimestamp,omitempty" yaml:"serverTimestamp,omitempty"`
	Source                   *JsonAddress           `json:"source,omitempty" yaml:"source,omitempty"`
	SourceDevice             int32                  `json:"sourceDevice,omitempty" yaml:"sourceDevice,omitempty"`
	SyncMessage              *JsonSyncMessage       `json:"syncMessage,omitempty" yaml:"syncMessage,omitempty"`
	Timestamp                int64                  `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
	TimestampISO             string                 `json:"timestampISO,omitempty" yaml:"timestampISO,omitempty"`
	Type                     string                 `json:"type,omitempty" yaml:"type,omitempty"`
	Typing                   *v0.JsonTypingMessage  `json:"typing,omitempty" yaml:"typing,omitempty"`
	Username                 string                 `json:"username,omitempty" yaml:"username,omitempty"`
	UUID                     string                 `json:"uuid,omitempty" yaml:"uuid,omitempty"`
}

type JsonMessageRequestResponseMessage struct {
	GroupId string       `json:"groupId,omitempty" yaml:"groupId,omitempty"`
	Person  *JsonAddress `json:"person,omitempty" yaml:"person,omitempty"`
	Type    string       `json:"type,omitempty" yaml:"type,omitempty"`
}

// JsonQuote: A quote is a reply to a previous message. ID is the sent time of the message being replied to
type JsonQuote struct {
	Attachments []*v0.JsonQuotedAttachment `json:"attachments,omitempty" yaml:"attachments,omitempty"` // list of files attached to the quoted message
	Author      *JsonAddress               `json:"author,omitempty" yaml:"author,omitempty"`           // the author of the message being quoted
	ID          int64                      `json:"id,omitempty" yaml:"id,omitempty"`                   // the client timestamp of the message being quoted
	Mentions    []*JsonMention             `json:"mentions,omitempty" yaml:"mentions,omitempty"`       // list of mentions in the quoted message
	Text        string                     `json:"text,omitempty" yaml:"text,omitempty"`               // the body of the message being quoted
}

type JsonReaction struct {
	Emoji               string       `json:"emoji,omitempty" yaml:"emoji,omitempty"`                             // the emoji to react with
	Remove              bool         `json:"remove,omitempty" yaml:"remove,omitempty"`                           // set to true to remove the reaction. requires emoji be set to previously reacted emoji
	TargetAuthor        *JsonAddress `json:"targetAuthor,omitempty" yaml:"targetAuthor,omitempty"`               // the author of the message being reacted to
	TargetSentTimestamp int64        `json:"targetSentTimestamp,omitempty" yaml:"targetSentTimestamp,omitempty"` // the client timestamp of the message being reacted to
}

type JsonReadMessage struct {
	Sender    *JsonAddress `json:"sender,omitempty" yaml:"sender,omitempty"`
	Timestamp int64        `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
}

type JsonSendMessageResult struct {
	Address             *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`
	IdentityFailure     string       `json:"identityFailure,omitempty" yaml:"identityFailure,omitempty"`
	NetworkFailure      bool         `json:"networkFailure,omitempty" yaml:"networkFailure,omitempty"`
	Success             *v0.Success  `json:"success,omitempty" yaml:"success,omitempty"`
	UnregisteredFailure bool         `json:"unregisteredFailure,omitempty" yaml:"unregisteredFailure,omitempty"`
}

type JsonSentTranscriptMessage struct {
	Destination              *JsonAddress      `json:"destination,omitempty" yaml:"destination,omitempty"`
	ExpirationStartTimestamp int64             `json:"expirationStartTimestamp,omitempty" yaml:"expirationStartTimestamp,omitempty"`
	IsRecipientUpdate        bool              `json:"isRecipientUpdate,omitempty" yaml:"isRecipientUpdate,omitempty"`
	Message                  *JsonDataMessage  `json:"message,omitempty" yaml:"message,omitempty"`
	Timestamp                int64             `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
	UnidentifiedStatus       map[string]string `json:"unidentifiedStatus,omitempty" yaml:"unidentifiedStatus,omitempty"`
}

type JsonSyncMessage struct {
	BlockedList            *JsonBlockedListMessage               `json:"blockedList,omitempty" yaml:"blockedList,omitempty"`
	Configuration          *v0.ConfigurationMessage              `json:"configuration,omitempty" yaml:"configuration,omitempty"`
	Contacts               *v0.JsonAttachment                    `json:"contacts,omitempty" yaml:"contacts,omitempty"`
	ContactsComplete       bool                                  `json:"contactsComplete,omitempty" yaml:"contactsComplete,omitempty"`
	FetchType              string                                `json:"fetchType,omitempty" yaml:"fetchType,omitempty"`
	Groups                 *v0.JsonAttachment                    `json:"groups,omitempty" yaml:"groups,omitempty"`
	MessageRequestResponse *JsonMessageRequestResponseMessage    `json:"messageRequestResponse,omitempty" yaml:"messageRequestResponse,omitempty"`
	ReadMessages           []*JsonReadMessage                    `json:"readMessages,omitempty" yaml:"readMessages,omitempty"`
	Request                string                                `json:"request,omitempty" yaml:"request,omitempty"`
	Sent                   *JsonSentTranscriptMessage            `json:"sent,omitempty" yaml:"sent,omitempty"`
	StickerPackOperations  []*v0.JsonStickerPackOperationMessage `json:"stickerPackOperations,omitempty" yaml:"stickerPackOperations,omitempty"`
	Verified               *JsonVerifiedMessage                  `json:"verified,omitempty" yaml:"verified,omitempty"`
	ViewOnceOpen           *JsonViewOnceOpenMessage              `json:"viewOnceOpen,omitempty" yaml:"viewOnceOpen,omitempty"`
}

type JsonVerifiedMessage struct {
	Destination *JsonAddress `json:"destination,omitempty" yaml:"destination,omitempty"`
	IdentityKey string       `json:"identityKey,omitempty" yaml:"identityKey,omitempty"`
	Timestamp   int64        `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
	Verified    string       `json:"verified,omitempty" yaml:"verified,omitempty"`
}

type JsonVersionMessage struct {
	Branch  string `json:"branch,omitempty" yaml:"branch,omitempty"`
	Commit  string `json:"commit,omitempty" yaml:"commit,omitempty"`
	Name    string `json:"name,omitempty" yaml:"name,omitempty"`
	Version string `json:"version,omitempty" yaml:"version,omitempty"`
}

type JsonViewOnceOpenMessage struct {
	Sender    *JsonAddress `json:"sender,omitempty" yaml:"sender,omitempty"`
	Timestamp int64        `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
}

type LeaveGroupRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // The account to use
	GroupID string `json:"groupID,omitempty" yaml:"groupID,omitempty"` // The group to leave
}

type LinkedDevices struct {
	Devices []*DeviceInfo `json:"devices,omitempty" yaml:"devices,omitempty"`
}

type LinkingURI struct {
	SessionId string `json:"session_id,omitempty" yaml:"session_id,omitempty"`
	Uri       string `json:"uri,omitempty" yaml:"uri,omitempty"`
}

// ListAccountsRequest: return all local accounts
type ListAccountsRequest struct {
	Request
}

type ListContactsRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"`
	Async   bool   `json:"async,omitempty" yaml:"async,omitempty"` // return results from local store immediately, refreshing from server afterward if needed. If false (default), block until all pending profiles have been retrieved.
}

type ListGroupsRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"`
}

type MarkReadRequest struct {
	Request
	Account    string       `json:"account,omitempty" yaml:"account,omitempty"`       // The account to interact with
	Timestamps []int64      `json:"timestamps,omitempty" yaml:"timestamps,omitempty"` // List of messages to mark as read
	To         *JsonAddress `json:"to,omitempty" yaml:"to,omitempty"`                 // The address that sent the message being marked as read
	When       int64        `json:"when,omitempty" yaml:"when,omitempty"`
}

// Profile: Information about a Signal user
type Profile struct {
	About          string        `json:"about,omitempty" yaml:"about,omitempty"`
	Address        *JsonAddress  `json:"address,omitempty" yaml:"address,omitempty"`
	Avatar         string        `json:"avatar,omitempty" yaml:"avatar,omitempty"` // path to avatar on local disk
	Capabilities   *Capabilities `json:"capabilities,omitempty" yaml:"capabilities,omitempty"`
	Color          string        `json:"color,omitempty" yaml:"color,omitempty"` // color of the chat with this user
	Emoji          string        `json:"emoji,omitempty" yaml:"emoji,omitempty"`
	ExpirationTime int32         `json:"expiration_time,omitempty" yaml:"expiration_time,omitempty"`
	InboxPosition  int32         `json:"inbox_position,omitempty" yaml:"inbox_position,omitempty"`
	Name           string        `json:"name,omitempty" yaml:"name,omitempty"`                 // The user's name from local contact names if available, or if not in contact list their Signal profile name
	ProfileName    string        `json:"profile_name,omitempty" yaml:"profile_name,omitempty"` // The user's Signal profile name
}

type ProfileList struct {
	Profiles []*Profile `json:"profiles,omitempty" yaml:"profiles,omitempty"`
}

// ReactRequest: react to a previous message
type ReactRequest struct {
	Request
	Reaction         *JsonReaction `json:"reaction,omitempty" yaml:"reaction,omitempty"`
	RecipientAddress *JsonAddress  `json:"recipientAddress,omitempty" yaml:"recipientAddress,omitempty"`
	RecipientGroupID string        `json:"recipientGroupId,omitempty" yaml:"recipientGroupId,omitempty"`
	Timestamp        int64         `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
	Username         string        `json:"username,omitempty" yaml:"username,omitempty"`
}

// RegisterRequest: begin the account registration process by requesting a phone number verification code. when the code is received, submit it with a verify request
type RegisterRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // the e164 phone number to register with
	Captcha string `json:"captcha,omitempty" yaml:"captcha,omitempty"` // See https://signald.org/articles/captcha/
	Voice   bool   `json:"voice,omitempty" yaml:"voice,omitempty"`     // set to true to request a voice call instead of an SMS for verification
}

// RemoveLinkedDeviceRequest: Remove a linked device from the Signal account. Only allowed when the local device id is 1
type RemoveLinkedDeviceRequest struct {
	Request
	Account  string `json:"account,omitempty" yaml:"account,omitempty"`   // The account to interact with
	DeviceId int64  `json:"deviceId,omitempty" yaml:"deviceId,omitempty"` // the ID of the device to unlink
}

// RequestSyncRequest: Request other devices on the account send us their group list, syncable config and contact list.
type RequestSyncRequest struct {
	Request
	Account       string `json:"account,omitempty" yaml:"account,omitempty"`             // The account to use
	Blocked       bool   `json:"blocked,omitempty" yaml:"blocked,omitempty"`             // request block list sync (default true)
	Configuration bool   `json:"configuration,omitempty" yaml:"configuration,omitempty"` // request configuration sync (default true)
	Contacts      bool   `json:"contacts,omitempty" yaml:"contacts,omitempty"`           // request contact sync (default true)
	Groups        bool   `json:"groups,omitempty" yaml:"groups,omitempty"`               // request group sync (default true)
}

// ResetSessionRequest: reset a session with a particular user
type ResetSessionRequest struct {
	Request
	Account   string       `json:"account,omitempty" yaml:"account,omitempty"` // The account to use
	Address   *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"` // the user to reset session with
	Timestamp int64        `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
}

// ResolveAddressRequest: Resolve a partial JsonAddress with only a number or UUID to one with both. Anywhere that signald accepts a JsonAddress will except a partial, this is a convenience function for client authors, mostly because signald doesn't resolve all the partials it returns
type ResolveAddressRequest struct {
	Request
	Account string       `json:"account,omitempty" yaml:"account,omitempty"` // The signal account to use
	Partial *JsonAddress `json:"partial,omitempty" yaml:"partial,omitempty"` // The partial address, missing fields
}

type SendRequest struct {
	Request
	Attachments      []*v0.JsonAttachment `json:"attachments,omitempty" yaml:"attachments,omitempty"`
	Mentions         []*JsonMention       `json:"mentions,omitempty" yaml:"mentions,omitempty"`
	MessageBody      string               `json:"messageBody,omitempty" yaml:"messageBody,omitempty"`
	Quote            *JsonQuote           `json:"quote,omitempty" yaml:"quote,omitempty"`
	RecipientAddress *JsonAddress         `json:"recipientAddress,omitempty" yaml:"recipientAddress,omitempty"`
	RecipientGroupID string               `json:"recipientGroupId,omitempty" yaml:"recipientGroupId,omitempty"`
	Timestamp        int64                `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
	Username         string               `json:"username,omitempty" yaml:"username,omitempty"`
}

type SendResponse struct {
	Results   []*JsonSendMessageResult `json:"results,omitempty" yaml:"results,omitempty"`
	Timestamp int64                    `json:"timestamp,omitempty" yaml:"timestamp,omitempty"`
}

// SetDeviceNameRequest: set this device's name. This will show up on the mobile device on the same account under
type SetDeviceNameRequest struct {
	Request
	Account    string `json:"account,omitempty" yaml:"account,omitempty"`         // The account to set the device name of
	DeviceName string `json:"device_name,omitempty" yaml:"device_name,omitempty"` // The device name
}

// SetExpirationRequest: Set the message expiration timer for a thread. Expiration must be specified in seconds, set to 0 to disable timer
type SetExpirationRequest struct {
	Request
	Account    string       `json:"account,omitempty" yaml:"account,omitempty"` // The account to use
	Address    *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`
	Expiration int32        `json:"expiration,omitempty" yaml:"expiration,omitempty"`
	Group      string       `json:"group,omitempty" yaml:"group,omitempty"`
}

type SetProfile struct {
	Request
	About      string `json:"about,omitempty" yaml:"about,omitempty"`
	Account    string `json:"account,omitempty" yaml:"account,omitempty"`       // The phone number of the account to use
	AvatarFile string `json:"avatarFile,omitempty" yaml:"avatarFile,omitempty"` // Path to new profile avatar file, if the avatar should be updated
	Emoji      string `json:"emoji,omitempty" yaml:"emoji,omitempty"`
	Name       string `json:"name,omitempty" yaml:"name,omitempty"` // New profile name. Set to empty string for no profile name
}

// TrustRequest: Trust another user's safety number using either the QR code data or the safety number text
type TrustRequest struct {
	Request
	Account      string       `json:"account,omitempty" yaml:"account,omitempty"`             // The account to interact with
	Address      *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`             // The user to query identity keys for
	QrCodeData   string       `json:"qr_code_data,omitempty" yaml:"qr_code_data,omitempty"`   // base64-encoded QR code data. required if safety_number is absent
	SafetyNumber string       `json:"safety_number,omitempty" yaml:"safety_number,omitempty"` // required if qr_code_data is absent
	TrustLevel   string       `json:"trust_level,omitempty" yaml:"trust_level,omitempty"`     // One of TRUSTED_UNVERIFIED, TRUSTED_VERIFIED or UNTRUSTED. Default is TRUSTED_VERIFIED
}

// TypingRequest: send a typing started or stopped message
type TypingRequest struct {
	Request
	Account string       `json:"account,omitempty" yaml:"account,omitempty"` // The account to use
	Address *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`
	Group   string       `json:"group,omitempty" yaml:"group,omitempty"`
	Typing  bool         `json:"typing,omitempty" yaml:"typing,omitempty"`
	When    int64        `json:"when,omitempty" yaml:"when,omitempty"`
}

// UpdateContactRequest: update information about a local contact
type UpdateContactRequest struct {
	Request
	Account       string       `json:"account,omitempty" yaml:"account,omitempty"`
	Address       *JsonAddress `json:"address,omitempty" yaml:"address,omitempty"`
	Color         string       `json:"color,omitempty" yaml:"color,omitempty"`
	InboxPosition int32        `json:"inbox_position,omitempty" yaml:"inbox_position,omitempty"`
	Name          string       `json:"name,omitempty" yaml:"name,omitempty"`
}

// UpdateGroupRequest: modify a group. Note that only one modification action may be preformed at once
type UpdateGroupRequest struct {
	Request
	Account             string              `json:"account,omitempty" yaml:"account,omitempty"` // The identifier of the account to interact with
	AddMembers          []*JsonAddress      `json:"addMembers,omitempty" yaml:"addMembers,omitempty"`
	Avatar              string              `json:"avatar,omitempty" yaml:"avatar,omitempty"`
	GroupID             string              `json:"groupID,omitempty" yaml:"groupID,omitempty"` // the ID of the group to update
	RemoveMembers       []*JsonAddress      `json:"removeMembers,omitempty" yaml:"removeMembers,omitempty"`
	ResetLink           bool                `json:"resetLink,omitempty" yaml:"resetLink,omitempty"` // regenerate the group link password, invalidating the old one
	Title               string              `json:"title,omitempty" yaml:"title,omitempty"`
	UpdateAccessControl *GroupAccessControl `json:"updateAccessControl,omitempty" yaml:"updateAccessControl,omitempty"` // note that only one of the access controls may be updated per request
	UpdateRole          *GroupMember        `json:"updateRole,omitempty" yaml:"updateRole,omitempty"`
	UpdateTimer         int32               `json:"updateTimer,omitempty" yaml:"updateTimer,omitempty"` // update the group timer.
}

// VerifyRequest: verify an account's phone number with a code after registering, completing the account creation process
type VerifyRequest struct {
	Request
	Account string `json:"account,omitempty" yaml:"account,omitempty"` // the e164 phone number being verified
	Code    string `json:"code,omitempty" yaml:"code,omitempty"`       // the verification code, dash (-) optional
}

type VersionRequest struct {
	Request
}
